@@ -1,22 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2007 by Joris Guisson                                   *
- *   joris.guisson@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "torrentgroup.h"
 #include <bcodec/bencoder.h>
@@ -121,22 +106,22 @@ void TorrentGroup::load(bt::BDictNode *dn)
     if (BDictNode *gp = dn->getDict(QByteArrayLiteral("policy"))) {
         // load the group policy
         if (gp->getValue(QByteArrayLiteral("default_save_location"))) {
-            policy.default_save_location = gp->getString(QByteArrayLiteral("default_save_location"), 0);
+            policy.default_save_location = gp->getString(QByteArrayLiteral("default_save_location"), nullptr);
             if (policy.default_save_location.length() == 0)
                 policy.default_save_location = QString(); // make sure that 0 length strings are loaded as null strings
         }
 
         if (gp->getValue(QByteArrayLiteral("default_move_on_completion_location"))) {
-            policy.default_move_on_completion_location = gp->getString(QByteArrayLiteral("default_move_on_completion_location"), 0);
+            policy.default_move_on_completion_location = gp->getString(QByteArrayLiteral("default_move_on_completion_location"), nullptr);
             if (policy.default_move_on_completion_location.length() == 0)
                 policy.default_move_on_completion_location = QString(); // make sure that 0 length strings are loaded as null strings
         }
 
         if (gp->getValue(QByteArrayLiteral("max_share_ratio")))
-            policy.max_share_ratio = gp->getString(QByteArrayLiteral("max_share_ratio"), 0).toFloat();
+            policy.max_share_ratio = gp->getString(QByteArrayLiteral("max_share_ratio"), nullptr).toFloat();
 
         if (gp->getValue(QByteArrayLiteral("max_seed_time")))
-            policy.max_seed_time = gp->getString(QByteArrayLiteral("max_seed_time"), 0).toFloat();
+            policy.max_seed_time = gp->getString(QByteArrayLiteral("max_seed_time"), nullptr).toFloat();
 
         if (gp->getValue(QByteArrayLiteral("max_upload_rate")))
             policy.max_upload_rate = gp->getInt(QByteArrayLiteral("max_upload_rate"));
@@ -157,7 +142,7 @@ void TorrentGroup::torrentRemoved(TorrentInterface *tor)
 void TorrentGroup::removeTorrent(TorrentInterface *tor)
 {
     torrents.erase(tor);
-    torrentRemoved(this);
+    Q_EMIT torrentRemoved(this);
 }
 
 void TorrentGroup::addTorrent(TorrentInterface *tor, bool new_torrent)
@@ -173,7 +158,7 @@ void TorrentGroup::addTorrent(TorrentInterface *tor, bool new_torrent)
     tor->setMaxSeedTime(policy.max_seed_time);
     tor->setTrafficLimits(policy.max_upload_rate * 1024, policy.max_download_rate * 1024);
 
-    torrentAdded(this);
+    Q_EMIT torrentAdded(this);
 }
 
 void TorrentGroup::policyChanged()
@@ -204,3 +189,5 @@ void TorrentGroup::loadTorrents(QueueManager *qman)
 }
 
 }
+
+#include "moc_torrentgroup.cpp"
